@@ -13,6 +13,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef TARGET_ARCH_DEFAULT
 # define TARGET_ARCH_DEFAULT 0
 #endif
@@ -22,7 +25,6 @@
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/newlib-stdint.h"
 # include "config/nds32/nds32.h"
